<?php
/**
 * th language file
 *
 * This file was initially built by fetching translations from other
 * Wiki projects. See the @url lines below. Additional translations
 * and fixes where done for DokuWiki by the people mentioned in the
 * lines starting with @author
 *
 * @url http://svn.wikimedia.org/viewvc/mediawiki/trunk/phase3/languages/messages/MessagesTh.php?view=co
 * @author Komgrit Niyomrath <n.komgrit@gmail.com>
 * @author Arthit Suriyawongkul <arthit@gmail.com>
 * @author Kittithat Arnontavilas <mrtomyum@gmail.com>
 * @author Thanasak Sompaisansin <jombthep@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“	';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'แก้ไขหน้านี้';
$lang['btn_source']            = 'ดูโค้ด';
$lang['btn_show']              = 'แสดงเพจ';
$lang['btn_create']            = 'สร้างเพจนี้';
$lang['btn_search']            = 'ค้นหา';
$lang['btn_save']              = 'บันทึก';
$lang['btn_preview']           = 'แสดงตัวอย่าง';
$lang['btn_top']               = 'กลับสู่ด้านบน';
$lang['btn_newer']             = '<< ใหม่กว่า';
$lang['btn_older']             = 'เก่ากว่า >>';
$lang['btn_revs']              = 'ฉบับเก่าๆ';
$lang['btn_recent']            = 'ปรับปรุงล่าสุด';
$lang['btn_upload']            = 'ส่งข้อมูลเข้าสู่ระบบ';
$lang['btn_cancel']            = 'ยกเลิก';
$lang['btn_index']             = 'ดัชนี';
$lang['btn_secedit']           = 'แก้ไข';
$lang['btn_login']             = 'ล็อกอิน';
$lang['btn_logout']            = 'ล็อกเอาต์';
$lang['btn_admin']             = 'ผู้ควบคุมระบบ';
$lang['btn_update']            = 'ปรับปรุง';
$lang['btn_delete']            = 'ลบ';
$lang['btn_back']              = 'ย้อนกลับ';
$lang['btn_backlink']          = 'หน้าที่ลิงก์มา';
$lang['btn_backtomedia']       = 'กลับไปยังหน้าเลือกไฟล์สื่อ';
$lang['btn_subscribe']         = 'เฝ้าดู';
$lang['btn_unsubscribe']       = 'เลิกเฝ้าดู';
$lang['btn_profile']           = 'แก้ข้อมูลผู้ใช้';
$lang['btn_reset']             = 'เริ่มใหม่';
$lang['btn_draft']             = 'แก้ไขเอกสารฉบับร่าง';
$lang['btn_recover']           = 'กู้คืนเอกสารฉบับร่าง';
$lang['btn_draftdel']          = 'ลบเอกสารฉบับร่าง';
$lang['btn_revert']            = 'กู้คืน';
$lang['btn_register']          = 'สร้างบัญชีผู้ใช้';
$lang['loggedinas']            = 'ลงชื่อเข้าใช้เป็น';
$lang['user']                  = 'ชื่อผู้ใช้:';
$lang['pass']                  = 'รหัสผ่าน';
$lang['newpass']               = 'รหัสผ่านใหม่';
$lang['oldpass']               = 'รหัสผ่านเดิม:';
$lang['passchk']               = 'พิมพ์รหัสผ่านอีกครั้ง:';
$lang['remember']              = 'จำชื่อและรหัสผ่าน';
$lang['fullname']              = 'ชื่อจริง:';
$lang['email']                 = 'อีเมล:';
$lang['profile']               = 'ข้อมูลส่วนตัวผู้ใช้';
$lang['badlogin']              = 'ขัดข้อง:';
$lang['minoredit']             = 'เป็นการแก้ไขเล็กน้อย';
$lang['draftdate']             = 'บันทึกฉบับร่างเมื่อ';
$lang['nosecedit']             = 'ในช่วงเวลาที่ผ่านมานี้เพจถูกแก้ไขไปแล้ว, เนื้อหาในเซคชั่นนี้ไม่ทันสมัย กรุณาโหลดเพจใหม่ทั้งหน้าแทน';
$lang['regmissing']            = 'ขออภัย คุณต้องกรอกให้ครบทุกช่อง';
$lang['reguexists']            = 'ชื่อบัญชีที่ใส่นั้นมีผู้อื่นได้ใช้แล้ว กรุณาเลือกชื่อผู้ใช้อื่น';
$lang['regsuccess']            = 'ผู้ใช้ถูกสร้างแล้ว และรหัสผ่านได้ถูกส่งไปทางอีเมลแล้ว';
$lang['regsuccess2']           = 'ชื่อบัญชีได้ถูกสร้างขึ้น';
$lang['regmailfail']           = 'ดูเหมือนจะมีข้อผิดพลาดในการส่งรหัสผ่านทางเมล์ กรุณาติดต่อผู้ดูแลระบบ';
$lang['regbadmail']            = 'รูปแบบอีเมลไม่ถูกต้อง ให้ใส่อีเมลให้ถูกต้องตามรูปแบบอีเมล หรือให้ทำช่องอีเมลให้ว่างแทน';
$lang['regbadpass']            = 'รหัสผ่านที่ใส่ไม่ถูกต้อง';
$lang['regpwmail']             = 'รหัสผ่านเข้าโดกุวิกิของคุณ';
$lang['reghere']               = 'คุณยังไม่มีบัญชีหรือ ก็แค่สร้างขึ้นมาสักอันหนึ่ง';
$lang['profna']                = 'วิกินี้ไม่รองรับการแก้ไขข้อมูลส่วนตัว';
$lang['profnochange']          = 'ไม่มีการเปลี่ยนแปลงข้อมูลส่วนตัว';
$lang['profnoempty']           = 'ไม่อนุญาติให้เว้นว่างชื่อ หรืออีเมล';
$lang['profchanged']           = 'ปรับปรุงข้อมูลส่วนตัวผู้ใช้สำเร็จ';
$lang['pwdforget']             = 'ลืมรหัสผ่านหรือ? เอาอันใหม่สิ';
$lang['resendna']              = 'วิกินี้ไม่รองรับการส่งรหัสผ่านซ้ำ';
$lang['resendpwdmissing']      = 'ขออภัย, คุณต้องกรอกทุกช่อง';
$lang['resendpwdnouser']       = 'ขออภัย, เราไม่พบผู้ใช้คนนี้ในฐานข้อมูลของเรา';
$lang['resendpwdbadauth']      = 'ขออภัย, รหัสนี้ยังใช้ไม่ได้ กรุณาตรวจสอบว่าคุณกดลิ้งค์ยืนยันแล้ว';
$lang['resendpwdconfirm']      = 'อีเมลยืนยันได้ถูกส่งไปที่อีเมลที่ได้ถูกเสนอ ก่อนที่อีเมลจะถูกส่งไปที่ชื่อบัญชีนั้น คุณต้องปฏิบัติตามคำแนะนำในอีเมลเพื่อยืนยันว่าหมายเลยบัญชีนั้นเป็นของคุณ';
$lang['resendpwdsuccess']      = 'รหัสผ่านใหม่ของคุณได้ถูกส่งให้แล้วทางอีเมล';
$lang['license']               = 'เว้นแต่จะได้แจ้งไว้เป็นอื่นใด เนื้อหาบนวิกินี้ถูกกำหนดสิทธิ์ไว้ภายใต้สัญญาอนุญาติต่อไปนี้:';
$lang['licenseok']             = 'โปรดทราบ: เมื่อเริ่มแก้ไขหน้านี้ ถือว่าคุณตกลงให้สิทธิ์กับเนื้อหาของคุณอยู่ภายใต้สัญญาอนุญาตินี้';
$lang['searchmedia']           = 'สืบค้นไฟล์ชื่อ:';
$lang['searchmedia_in']        = 'สืบค้นใน %s';
$lang['txt_upload']            = 'เลือกไฟล์ที่จะอัพโหลด';
$lang['txt_filename']          = 'อัพโหลดเป็น(ตัวเลือก)';
$lang['txt_overwrt']           = 'เขียนทับไฟล์ที่มีอยู่แล้ว';
$lang['lockedby']              = 'ตอนนี้ถูกล๊อคโดย';
$lang['lockexpire']            = 'การล๊อคจะหมดอายุเมื่อ';
$lang['js']['willexpire']            = 'การล๊อคเพื่อแก้ไขหน้านี้กำลังจะหมดเวลาในอีก \n นาที เพื่อที่จะหลีกเลี่ยงข้อขัดแย้งให้ใช้ปุ่ม "Preview" เพื่อรีเซ็ทเวลาใหม่';
$lang['js']['notsavedyet']     = 'การแก้ไขที่ไม่ได้บันทึกจะสูญหาย \n ต้องการทำต่อจริงๆหรือ?';
$lang['rssfailed']             = 'มีข้อผิดพลาดขณะดูดฟีดนี้';
$lang['nothingfound']          = 'ไม่พบสิ่งใด';
$lang['mediaselect']           = 'ไฟล์สื่อ';
$lang['fileupload']            = 'อัปโหลด';
$lang['uploadsucc']            = 'อัปโหลดสำเร็จ';
$lang['uploadfail']            = 'เกิดความขัดข้องในการอัปโหลด';
$lang['uploadwrong']           = 'การอัพโหลดถูกปฏิเสธ ส่วนขยายไฟล์นี้ต้องห้าม!';
$lang['uploadexist']           = 'ไฟล์นี้มีอยู่แล้ว ไม่มีการบันทึกใดๆเกิดขึ้น';
$lang['uploadbadcontent']      = 'เนื้อหาที่อัพโหลดไม่ตรงกับส่วนขยายไฟล์ %s ';
$lang['uploadspam']            = 'การอัพโหลดถูกกีดกันจากบัญชีดำสแปม';
$lang['uploadxss']             = 'ไฟล์นี้มีส่วนประกอบของโค้ดเอชทีเอ็มแอลหรือสคริปต์ ซึ่งอาจก่อให้เกิดความผิดพลาดในการแสดงผลของเว็บเบราว์เซอร์';
$lang['uploadsize']            = 'ไฟล์ที่อัพโหลดใหญ่เกินไป (สูงสุด %s)';
$lang['deletesucc']            = 'ไฟล์ "%s" ถูกลบ';
$lang['deletefail']            = '"%s" ไม่สามารถลบได้ - ให้ตรวจสอบสิทธิ์การใช้ของคุณ';
$lang['mediainuse']            = 'ไฟล์ "%s" ไม่ได้ถูกลบ - มันถูกใช้อยู่';
$lang['namespaces']            = 'เนมสเปซ';
$lang['mediafiles']            = 'มีไฟล์พร้อมใช้อยู่ใน';
$lang['js']['searchmedia']     = 'ค้นหาไฟล์';
$lang['js']['keepopen']        = 'เปิดหน้าต่างไว้ระหว่างที่เลือก';
$lang['js']['hidedetails']     = 'ซ่อนรายละเอียด';
$lang['js']['nosmblinks']      = 'เชื่อมไปยังหน้าต่างแบ่งปัน ทำงานได้กับเฉพาะไมโครซอฟท์อินเตอร์เน็ตเอ็กซโปรเรอร์(IE) คุณยังคงสามารถคัดลอกและแปะลิ้งค์ได้';
$lang['js']['linkwiz']         = 'ลิงค์วิเศษ';
$lang['js']['linkto']          = 'ลิงค์ไป:';
$lang['js']['del_confirm']     = 'ต้องการลบรายการที่เลือกจริงๆหรือ?';
$lang['mediausage']            = 'ให้ใช้ไวยกรณ์ต่อไปนี้เพื่ออ้างอิงไฟล์นี้';
$lang['mediaview']             = 'ดูไฟล์ต้นฉบับ';
$lang['mediaroot']             = 'ราก(รูท)';
$lang['mediaupload']           = 'อัพโหลดไฟล์ไปยังเนมสเปซปัจจุบันจากที่นี่ หากจะสร้างเนมสเปซย่อย ให้พิมพ์ต่อข้อความของคุณหลังชื่อไฟล์ในช่อง "อัพโหลดเป็น" โดยให้คั่นด้วยโคล่อน(:)';
$lang['mediaextchange']        = 'ส่วนขยายไฟล์ถูกเปลี่ยนจาก .%s ไปเป็น .%s!';
$lang['reference']             = 'อ้างอิงสำหรับ';
$lang['ref_inuse']             = 'ไม่สามารถลบไฟล์ได้ เพราะมันยังคงถูกใช้โดยเพจดังต่อไปนี้:';
$lang['ref_hidden']            = 'มีการอ้างอิงบางรายการในเพจ คุณไม่มีสิทธิ์ในการอ่าน';
$lang['hits']                  = 'คำที่ตรงกัน';
$lang['quickhits']             = 'ชื่อเพจที่ตรงกัน';
$lang['toc']                   = 'สารบัญ';
$lang['current']               = 'ฉบับปัจจุบัน';
$lang['yours']                 = 'ฉบับของคุณ';
$lang['diff']                  = 'แสดงจุดแตกต่างกับฉบับปัจจุบัน';
$lang['diff2']                 = 'แสดงจุดแตกต่างระหว่างฉบับที่เลือกไว้';
$lang['line']                  = 'บรรทัด';
$lang['breadcrumb']            = 'ตามรอย';
$lang['youarehere']            = 'คุณอยู่ที่นี่';
$lang['lastmod']               = 'แก้ไขครั้งล่าสุด';
$lang['by']                    = 'โดย';
$lang['deleted']               = 'ถูกถอดออก';
$lang['created']               = 'ถูกสร้าง';
$lang['restored']              = 'ย้อนไปรุ่นก่อนหน้า (%s)';
$lang['external_edit']         = 'แก้ไขภายนอก';
$lang['summary']               = 'สรุป(หมายเหตุ)การแก้ไขนี้';
$lang['noflash']               = 'ต้องการตัวเล่นแฟลช <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> เพื่อแสดงผลเนื้อหานี้';
$lang['download']              = 'ดาวน์โหลดสนิปเป็ด(Snippet)';
$lang['mail_newpage']          = 'เพิ่มเพจแล้ว:';
$lang['mail_changed']          = 'แก้ไขเพจแล้ว:';
$lang['mail_new_user']         = 'ผู้ใช้คนใหม่:';
$lang['mail_upload']           = 'ไฟล์อัพโหลดแล้ว:';
$lang['qb_bold']               = 'ทำตัวหนา';
$lang['qb_italic']             = 'ทำตัวเอียง';
$lang['qb_underl']             = 'ขีดเส้นใต้ข้อความ';
$lang['qb_code']               = 'ข้อความเป็นโค้ดโปรแกรม';
$lang['qb_strike']             = 'ขีดฆ่าข้อความ';
$lang['qb_h1']                 = 'หัวเรื่องระดับที่ 1';
$lang['qb_h2']                 = 'หัวเรื่องระดับที่ 2';
$lang['qb_h3']                 = 'หัวเรื่องระดับที่ 3';
$lang['qb_h4']                 = 'หัวเรื่องระดับที่ 4';
$lang['qb_h5']                 = 'หัวเรื่องระดับที่ 5';
$lang['qb_h']                  = 'หัวเรื่อง';
$lang['qb_hs']                 = 'เลือกหัวเรื่อง';
$lang['qb_hplus']              = 'หัวเรื่องที่สูงกว่า';
$lang['qb_hminus']             = 'หัวเรื่องที่ต่ำกว่า';
$lang['qb_hequal']             = 'หัวเรื่องระดับเดียวกัน';
$lang['qb_link']               = 'ลิงก์ภายในเว็บ';
$lang['qb_extlink']            = 'ลิงก์ไปที่อื่น (อย่าลืม http:// นำหน้าเสมอ)';
$lang['qb_hr']                 = 'เส้นนอน';
$lang['qb_ol']                 = 'รายการที่เรียงลำดับแล้ว';
$lang['qb_ul']                 = 'รายการที่ยังไม่ได้เรียงลำดับ';
$lang['qb_media']              = 'เพิ่มภาพและไฟล์อื่นๆ';
$lang['qb_sig']                = 'ลายเซ็นพร้อมลงเวลา';
$lang['qb_smileys']            = 'ภาพแสดงอารมณ์';
$lang['qb_chars']              = 'อักขระพิเศษ';
$lang['upperns']               = 'กระโดดขึ้นไปยังเนมสเปซแม่';
$lang['admin_register']        = 'สร้างบัญชีผู้ใช้';
$lang['metaedit']              = 'แก้ไขข้อมูลเมต้า';
$lang['metasaveerr']           = 'มีข้อผิดพลาดในการเขียนข้อมูลเมต้า';
$lang['metasaveok']            = 'บันทึกเมต้าดาต้าแล้ว';
$lang['img_backto']            = 'กลับไปยัง';
$lang['img_title']             = 'ชื่อภาพ';
$lang['img_caption']           = 'คำบรรยายภาพ';
$lang['img_date']              = 'วันที่';
$lang['img_fname']             = 'ชื่อไฟล์';
$lang['img_fsize']             = 'ขนาดภาพ';
$lang['img_artist']            = 'ผู้สร้างสรรค์';
$lang['img_copyr']             = 'ผู้ถือลิขสิทธิ์';
$lang['img_format']            = 'รูปแบบ';
$lang['img_camera']            = 'กล้อง';
$lang['img_keywords']          = 'คำหลัก';
$lang['subscribe_success']     = 'เพิ่ม %s เข้าไปในรายชื่อสมาชิกลงทะเบียนสำหรับ %s';
$lang['subscribe_error']       = 'มีข้อผิดพลาดในการเพิ่ม %s ในรายชื่อสมัครสมาชิกสำหรับ %s';
$lang['subscribe_noaddress']   = 'ไม่มีที่อยู่ที่ตรงกับชื่อล็อกอินของคุณ ชื่อคุณไม่สามารถถูกเพิ่มเข้าไปในรายชื่อสมัครสมาชิก';
$lang['unsubscribe_success']   = 'ถอด % ออกจากรายชื่อสมัครสมาชิกของ %s';
$lang['unsubscribe_error']     = 'มีข้อผิดพลาดในการถอด %s ออกจากรายชื่อสมาชิกของ %s';
$lang['authmodfailed']         = 'มีการกำหนดค่าสิทธิ์ผู้ใช้ไว้ไม่ดี กรุณาแจ้งผู้ดูแลระบบวิกิของคุณ';
$lang['authtempfail']          = 'ระบบตรวจสอบสิทธิ์ผู้ใช้ไม่พร้อมใช้งานชั่วคราว หากสถานการณ์ยังไม่เปลี่ยนแปลง กรุณาแจ้งผู้ดูแลระบวิกิของคุณ';
$lang['i_chooselang']          = 'เลือกภาษาของคุณ';
$lang['i_installer']           = 'ตัวติดตั้งโดกุวิกิ';
$lang['i_wikiname']            = 'ชื่อวิกิ';
$lang['i_enableacl']           = 'เปิดระบบ ACL(แนะนำ)';
$lang['i_superuser']           = 'ซุปเปอร์ยูสเซอร์';
$lang['i_problems']            = 'ตัวติดตั้งพบปัญหาบางประการ ตามที่ระบุด้านล่าง คุณไม่สามารถทำต่อได้จนกว่าจะได้แก้ไขสิ่งเหล่านั้น';
$lang['i_modified']            = 'ด้วยเหตุผลด้านความปลอดภัย สคริปต์นี้จะทำงานกับเฉพาะโดกุวิกิที่ติดตั้งใหม่หรือยังไม่ได้ดัดแปลงแก้ไข
คุณควรเลือกระหว่างคลี่ไฟล์จากแพคเกจที่ได้ดาวน์โหลดมาอีกครั้ง หรือศึกษาจากคู่มือ
<a href="http://dokuwiki.org/install">Dokuwiki installation instructions</a>';
$lang['i_funcna']              = 'PHP function <code>%s</code> ไม่สามารถใช้งานได้ อาจเป็นเพราะผู้ให้บริการโฮสไม่เปิดให้ใช้งาน';
$lang['i_phpver']              = 'PHP รุ่นที่คุณกำลังใช้งานอยู่คือ <code>%s</code> คุณจำเป็นต้องอัพเกรด PHP ให้เป็นรุ่น <code>%s</code> หรือสูงกว่า';
$lang['i_permfail']            = '<code>%s</code> DokuWiki ไม่สามารถเขียนข้อมูลได้ ต้องตั้งค่าสิทธิ์การอนุญาตของไดเรคทอรีนี้เสียก่อน!';
$lang['i_confexists']          = '<code>%s</code> ถูกใช้งานไปแล้ว';
$lang['i_writeerr']            = 'ไม่สามารถสร้าง <code>%s</code>. ตรวจสอบสิทธิ์การอนุญาตของไดเรคทอรีหรือไฟล์ แล้วสร้างไฟล์ด้วยตนเอง';
$lang['i_policy']              = 'นโยบายสิทธิ์เข้าถึง(ACL)ตั้งต้น';
$lang['i_pol0']                = 'วิกิเปิดกว้าง (ใครก็ อ่าน, เขียน, อัพโหลดได้)';
$lang['i_pol1']                = 'วิกิสาธารณะ (ทุกคนอ่านได้, เขียน และ อัพโหลดเฉพาะผู้ใช้ที่ลงทะเบียนแล้ว)';
$lang['i_pol2']                = 'วิกิภายใน (อ่าน, เขียน, อัพโหลด สำหรับผู้ใช้ที่ลงทะเบียนแล้วเท่านั้น)';
$lang['i_retry']               = 'ลองใหม่';
$lang['years']                 = '%d ปีก่อน';
$lang['months']                = '%d เดือนก่อน';
$lang['weeks']                 = '%d สัปดาห์ก่อน';
$lang['days']                  = '%d วันก่อน';
$lang['hours']                 = '%d ชั่วโมงก่อน';
$lang['minutes']               = '%d นาทีก่อน';
$lang['seconds']               = '%d วินาทีก่อน';
